argus_api.exceptions package — Argus-Toolbelt 1.0 documentation

# argus_api.exceptions package

## Submodules

## argus_api.exceptions.http module

exception `argus_api.exceptions.http.` `AccessDeniedException`(json_or_response, errors=None)

  Bases: `argus_api.exceptions.http.ArgusException`

  Used for HTTP 403

exception `argus_api.exceptions.http.` `ArgusException`(json_or_response, errors=None)

  Bases: `Exception`

exception `argus_api.exceptions.http.` `AuthenticationFailedException`(json_or_response, errors=None)

  Bases: `argus_api.exceptions.http.ArgusException`

  Used for HTTP 401

exception `argus_api.exceptions.http.` `MultipleValidationErrorException`

  Bases: `Exception`

exception `argus_api.exceptions.http.` `ObjectNotFoundException`(json_or_response, errors=None)

  Bases: `argus_api.exceptions.http.ArgusException`

  Used for HTTP 404

exception `argus_api.exceptions.http.` `ValidationErrorException`(json_or_response, errors=None)

  Bases: `argus_api.exceptions.http.ArgusException`

  Used for HTTP 412

## Module contents